@@ -21,9 +21,6 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <fcntl.h>
-#include <sys/stat.h>
-#include <unistd.h>
 #include <string.h>
 #include <stdlib.h>
 
@@ -31,16 +28,18 @@
 #include "games-scores.h"
 #include "games-scores-backend.h"
 
+#include "games-setgid-io.h"
+
 G_DEFINE_TYPE (GamesScoresBackend, games_scores_backend, G_TYPE_OBJECT);
 
 static void
-games_scores_backend_finalize (GamesScoresBackend *backend)
+games_scores_backend_finalize (GamesScoresBackend * backend)
 {
 
 }
 
 static void
-games_scores_backend_class_init (GamesScoresBackendClass *klass)
+games_scores_backend_class_init (GamesScoresBackendClass * klass)
 {
   GObjectClass *oclass = G_OBJECT_CLASS (klass);
 
@@ -49,24 +48,24 @@ games_scores_backend_class_init (GamesScoresBackendClass *klass)
 }
 
 static void
-games_scores_backend_init (GamesScoresBackend *backend)
+games_scores_backend_init (GamesScoresBackend * backend)
 {
-  backend->priv = G_TYPE_INSTANCE_GET_PRIVATE (backend, 
+  backend->priv = G_TYPE_INSTANCE_GET_PRIVATE (backend,
 					       GAMES_TYPE_SCORES_BACKEND,
 					       GamesScoresBackendPrivate);
 }
 
-GamesScoresBackend *games_scores_backend_new (GamesScoreStyle style,
-					      gchar *basename,
-					      gchar *name)
+GamesScoresBackend *
+games_scores_backend_new (GamesScoreStyle style,
+			  gchar * basename, gchar * name)
 {
   GamesScoresBackend *backend;
   gchar *fullname;
 
-  backend = GAMES_SCORES_BACKEND (g_object_new (GAMES_TYPE_SCORES_BACKEND, 
+  backend = GAMES_SCORES_BACKEND (g_object_new (GAMES_TYPE_SCORES_BACKEND,
 						NULL));
 
-  if (name[0] == '\0') /* Name is "" */
+  if (name[0] == '\0')		/* Name is "" */
     fullname = g_strjoin (".", basename, "scores", NULL);
   else
     fullname = g_strjoin (".", basename, name, "scores", NULL);
@@ -85,32 +84,27 @@ GamesScoresBackend *games_scores_backend_new (GamesScoreStyle style,
 /* Get a lock on the scores file. Block until it is available. 
  * This also supplies the file descriptor we need. The return value
  * is whether we were succesful or not. */
-static gboolean games_scores_backend_get_lock (GamesScoresBackend *self)
+static gboolean
+games_scores_backend_get_lock (GamesScoresBackend * self)
 {
-  struct flock lock;
   gint error;
 
   if (self->priv->fd != -1) {
     /* Assume we already have the lock and rewind the file to
      * the beginning. */
-    lseek (self->priv->fd, 0, SEEK_SET);
-    return TRUE; /* Assume we already have the lock. */
+    setgid_io_seek (self->priv->fd, 0, SEEK_SET);
+    return TRUE;		/* Assume we already have the lock. */
   }
 
-  self->priv->fd = open (self->priv->filename, O_RDWR);
+  self->priv->fd = setgid_io_open (self->priv->filename, O_RDWR);
   if (self->priv->fd == -1) {
     return FALSE;
   }
 
-  lock.l_type = F_WRLCK;
-  lock.l_whence = SEEK_SET;
-  lock.l_start = 0;
-  lock.l_len = 0;
-
-  error = fcntl (self->priv->fd, F_SETLKW, &lock);
+  error = setgid_io_lock (self->priv->fd);
 
   if (error == -1) {
-    close (self->priv->fd);
+    setgid_io_close (self->priv->fd);
     self->priv->fd = -1;
     return FALSE;
   }
@@ -120,22 +114,16 @@ static gboolean games_scores_backend_get_lock (GamesScoresBackend *self)
 
 /* Release the lock on the scores file and dispose of the fd. */
 /* We ignore errors, there is nothing we can do about them. */
-static void games_scores_backend_release_lock (GamesScoresBackend *self)
+static void
+games_scores_backend_release_lock (GamesScoresBackend * self)
 {
-  struct flock lock;
-
   /* We don't have a lock, ignore this call. */
   if (self->priv->fd == -1)
     return;
 
-  lock.l_type = F_UNLCK;
-  lock.l_whence = SEEK_SET;
-  lock.l_start = 0;
-  lock.l_len = 0;
+  setgid_io_unlock (self->priv->fd);
 
-  fcntl (self->priv->fd, F_SETLKW, &lock);
-
-  close (self->priv->fd);
+  setgid_io_close (self->priv->fd);
 
   self->priv->fd = -1;
 }
@@ -143,7 +131,8 @@ static void games_scores_backend_release_lock (GamesScoresBackend *self)
 /* You can alter the list returned by this function, but you must
  * make sure you set it again with the _set_scores method or discard it
  * with with the _discard_scores method. Otherwise deadlocks will ensue. */
-GList *games_scores_backend_get_scores (GamesScoresBackend *self) 
+GList *
+games_scores_backend_get_scores (GamesScoresBackend * self)
 {
   gchar *buffer;
   gchar *eol;
@@ -157,14 +146,13 @@ GList *games_scores_backend_get_scores (GamesScoresBackend *self)
   GList *t;
 
   /* Check for a change in the scores file and update if necessary. */
-  error = stat (self->priv->filename, &info);
+  error = setgid_io_stat (self->priv->filename, &info);
 
   /* If an error occurs then we give up on the file and return NULL. */
   if (error != 0)
     return NULL;
 
-  if ((info.st_mtime > self->priv->timestamp) || 
-      (self->scores_list == NULL)) {
+  if ((info.st_mtime > self->priv->timestamp) || (self->scores_list == NULL)) {
     self->priv->timestamp = info.st_mtime;
 
     /* Dump the old list of scores. */
@@ -190,7 +178,7 @@ GList *games_scores_backend_get_scores (GamesScoresBackend *self)
     length = 0;
     do {
       target -= length;
-      length = read (self->priv->fd, buffer, info.st_size);
+      length = setgid_io_read (self->priv->fd, buffer, info.st_size);
       if (length == -1) {
 	games_scores_backend_release_lock (self);
 	g_free (buffer);
@@ -210,10 +198,12 @@ GList *games_scores_backend_get_scores (GamesScoresBackend *self)
     while (eol != NULL) {
       *eol++ = '\0';
       timestr = strchr (scorestr, ' ');
-      if (timestr == NULL) break;
+      if (timestr == NULL)
+	break;
       *timestr++ = '\0';
       namestr = strchr (timestr, ' ');
-      if (namestr == NULL) break;
+      if (namestr == NULL)
+	break;
       *namestr++ = '\0';
       /* At this point we have three strings, all null terminated. All
        * part of the original buffer. */
@@ -237,66 +227,73 @@ GList *games_scores_backend_get_scores (GamesScoresBackend *self)
     }
 
     g_free (buffer);
-  } 
+  }
 
   /* FIXME: Sort the scores! We shouldn't rely on the file being sorted. */
 
   return self->scores_list;
 }
 
-void games_scores_backend_set_scores (GamesScoresBackend *self,
-				      GList *list)
+gboolean
+games_scores_backend_set_scores (GamesScoresBackend * self, GList * list)
 {
-    GList *s;
-    GamesScore *d;
-    gchar *buffer;
-    gchar dtostrbuf[G_ASCII_DTOSTR_BUF_SIZE];
+  GList *s;
+  GamesScore *d;
+  gchar *buffer;
+  gint output_length = 0;
+  gchar dtostrbuf[G_ASCII_DTOSTR_BUF_SIZE];
 
-    if (!games_scores_backend_get_lock (self))
-      return;
+  if (!games_scores_backend_get_lock (self))
+    return FALSE;
 
-    self->scores_list = list;
+  self->scores_list = list;
 
-    s = list;
-    while (s != NULL) {
-      gdouble rscore;
-      guint64 rtime;
-      gchar *rname;
+  s = list;
+  while (s != NULL) {
+    gdouble rscore;
+    guint64 rtime;
+    gchar *rname;
 
-      d = (GamesScore *)s->data;
-      rscore = 0.0;
-      switch (self->priv->style) {
-      case GAMES_SCORES_STYLE_PLAIN_DESCENDING:
-      case GAMES_SCORES_STYLE_PLAIN_ASCENDING:
-	rscore = d->value.plain;
-	break;
-      case GAMES_SCORES_STYLE_TIME_DESCENDING:
-      case GAMES_SCORES_STYLE_TIME_ASCENDING:
-	rscore = d->value.time_double;
-	break;
-      }
-      rtime = d->time;
-      rname = d->name;
-
-      buffer = g_strdup_printf ("%s %lld %s\n", 
-				g_ascii_dtostr (dtostrbuf, sizeof (dtostrbuf), 
-						rscore),
-				rtime, rname); 
-      write (self->priv->fd, buffer, strlen (buffer));
-      /* Ignore any errors and blunder on. */
-      g_free (buffer);
-
-      s = g_list_next (s);
+    d = (GamesScore *) s->data;
+    rscore = 0.0;
+    switch (self->priv->style) {
+    case GAMES_SCORES_STYLE_PLAIN_DESCENDING:
+    case GAMES_SCORES_STYLE_PLAIN_ASCENDING:
+      rscore = d->value.plain;
+      break;
+    case GAMES_SCORES_STYLE_TIME_DESCENDING:
+    case GAMES_SCORES_STYLE_TIME_ASCENDING:
+      rscore = d->value.time_double;
+      break;
     }
+    rtime = d->time;
+    rname = d->name;
 
-    /* Update the timestamp so we don't reread the scores unnecessarily. */
-    self->priv->timestamp = time (NULL);
+    buffer = g_strdup_printf ("%s %lld %s\n",
+			      g_ascii_dtostr (dtostrbuf, sizeof (dtostrbuf),
+					      rscore), rtime, rname);
+    setgid_io_write (self->priv->fd, buffer, strlen (buffer));
+    output_length += strlen (buffer);
+    /* Ignore any errors and blunder on. */
+    g_free (buffer);
 
-    games_scores_backend_release_lock (self);
+    s = g_list_next (s);
+  }
 
- }
+  /* Remove any content in the file that hasn't yet been overwritten. */
+  setgid_io_truncate (self->priv->fd, output_length--);
+
+  /* Update the timestamp so we don't reread the scores unnecessarily. */
+  self->priv->timestamp = time (NULL);
+
+  games_scores_backend_release_lock (self);
+
+  return TRUE;
 
-void games_scores_backend_discard_scores (GamesScoresBackend *self)
-{ 
-    games_scores_backend_release_lock (self);
+}
+
+void
+games_scores_backend_discard_scores (GamesScoresBackend * self)
+{
+  games_scores_backend_release_lock (self);
 }
